# SEKV-E

SEKV-E is a Python-based parameters extractor for the simplified EKV model, which is developed by ICLAB, EPFL. While it has been developed to serve the needs of low-power analog circuit designs. 


## Install

Now, the project only support the install method using git command. We are working on making this project availalbe on various distribution like `pip` and `conda`. Try the following command to clone this project to your space.

```
git clone https://gitlab.com/moscm/sekv-e.git
```

## Authors and acknowledgment
Hung-Chi Han, doctoral assistant in ICLAB, EPFL, Lausanne, Switzerland.

## License
see [LICENSE](LICENSE).

